scriptDir = 'scripts'
source(file.path(scriptDir, 'setup.R'))

assayMetadata = fread(file.path(paramDir, 'assay_metadata_clinchem.csv'))
ingredMetadata = fread(file.path(paramDir, 'ingred_metadata_clinchem.csv'))

minPersonPos = 5

########################################

dMeas = readRDS(file.path(dataDir, 'meas_screen_conf.rds'))
dMeasDrugExp = readRDS(file.path(dataDir, 'meas_drug_exp.rds'))

dSummary = dMeasDrugExp[, .(n_person_fp = uniqueN(person_id[measurement_result == 'pos_neg']),
                            n_person_pos = uniqueN(person_id[measurement_result != 'neg']),
                            n_neg = sum(measurement_result == 'neg'),
                            n_fp = sum(measurement_result == 'pos_neg'),
                            n_pos = sum(measurement_result != 'neg')),
                            by = .(screen_id, ingred_name)]

dAssaySummary = dMeas[, .(n_result = .N), keyby = .(screen_target, measurement_result)]
dAssaySummary = dcast(dAssaySummary, screen_target ~ measurement_result,
                      value.var = 'n_result')

fwrite(dAssaySummary, file.path(resultDir, 'counts_clinchem.csv'))

########################################
# calculate ORfp for targets

dMeasFp = dMeas[measurement_result %in% c('neg', 'pos_neg')]
dMeasFp[, value_num := as.numeric(measurement_result == 'pos_neg')]

dSummaryKeep = dSummary[n_person_fp >= minPersonPos][
  ingredMetadata[ingred_category == 'assay target', !'ingred_category'],
  on = c('screen_id', 'ingred_name'), nomatch = NULL]

dStatsFpTargets = foreach(di = iter(dSummaryKeep, by = 'row'), .combine = rbind) %dopar% {
  dInput = getModelInput(dMeasFp, dMeasDrugExp, di$screen_id,
                         di$ingred_name, assayIdName = 'screen_id')
  s = getLogisticStats(dInput, di$ingred_name, pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}

########################################
# calculate ORfp for non-targets

dSummaryKeep = dSummary[n_person_fp >= minPersonPos][
  !ingredMetadata[ingred_category == 'assay target', !'ingred_category'],
  on = c('screen_id', 'ingred_name')]

timeStart = Sys.time()

dStatsFpNon = foreach(di = iter(dSummaryKeep, by = 'row'), .combine = rbind) %dopar% {
  assayTargets = ingredMetadata[screen_id == di$screen_id &
                                   ingred_category == 'assay target']$ingred_name

  dInput = getModelInput(dMeasFp, dMeasDrugExp, di$screen_id,
                         c(di$ingred_name, assayTargets), assayIdName = 'screen_id')
  dInput[, assay_target := rowSums(.SD) > 0, .SDcols = assayTargets]

  s = getLogisticStats(dInput, c(di$ingred_name, 'assay_target'), pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}

timeElapsedFp = Sys.time() - timeStart

########################################
# combine ORfp stats and run ash

dStatsFp = rbind(dStatsFpTargets, dStatsFpNon)
dStatsFp = cbind(dStatsFp, getAshStats(dStatsFp))

dStatsFp = merge(assayMetadata[, !'cutoff_ng_ml'], dStatsFp, by = 'screen_id')
setorder(dStatsFp, screen_target, -PosteriorMean)

dStatsFp[, `:=`(or = exp(PosteriorMean),
                or_lower = exp(credint_lower),
                or_upper = exp(credint_upper))]

fwrite(dStatsFp, file.path(resultDir, 'stats_clinchem_falsepos.csv'))

########################################
# calculate ORp for targets

dMeasP = copy(dMeas)
dMeasP[, value_num := as.numeric(measurement_result %in% c('pos_neg', 'pos_pos'))]

dSummaryKeep = dSummary[n_person_pos >= minPersonPos][
  ingredMetadata[ingred_category == 'assay target', !'ingred_category'],
  on = c('screen_id', 'ingred_name'), nomatch = NULL]

dStatsPTargets = foreach(di = iter(dSummaryKeep, by = 'row'), .combine = rbind) %dopar% {
  dInput = getModelInput(dMeasP, dMeasDrugExp, di$screen_id,
                         di$ingred_name, assayIdName = 'screen_id')
  s = getLogisticStats(dInput, di$ingred_name, pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}

########################################
# calculate ORp for non-targets

dSummaryKeep = dSummary[n_person_pos >= minPersonPos][
  !ingredMetadata[ingred_category == 'assay target', !'ingred_category'],
  on = c('screen_id', 'ingred_name')]

timeStart = Sys.time()

dStatsPNon = foreach(di = iter(dSummaryKeep, by = 'row'), .combine = rbind) %dopar% {
  assayTargets = ingredMetadata[screen_id == di$screen_id &
                                  ingred_category == 'assay target']$ingred_name

  dInput = getModelInput(dMeasP, dMeasDrugExp, di$screen_id,
                         c(di$ingred_name, assayTargets), assayIdName = 'screen_id')
  dInput[, assay_target := rowSums(.SD) > 0, .SDcols = assayTargets]

  s = getLogisticStats(dInput, c(di$ingred_name, 'assay_target'), pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}

timeElapsedP = Sys.time() - timeStart

########################################
# combine ORp stats and run ash

dStatsP = rbind(dStatsPTargets, dStatsPNon)
dStatsP = cbind(dStatsP, getAshStats(dStatsP))

dStatsP = merge(assayMetadata[, !'cutoff_ng_ml'], dStatsP, by = 'screen_id')
setorder(dStatsP, screen_target, -PosteriorMean)

dStatsP[, `:=`(or = exp(PosteriorMean),
               or_lower = exp(credint_lower),
               or_upper = exp(credint_upper))]

fwrite(dStatsP, file.path(resultDir, 'stats_clinchem_pos.csv'))
