scriptDir = 'scripts'
source(file.path(scriptDir, 'setup.R'))

params = fread(file.path(paramDir, 'analysis_params.csv'))
assayMetadata = fread(file.path(paramDir, 'assay_metadata.csv'))
assayResultMetadata = fread(file.path(paramDir, 'assay_result_metadata.csv'))
targetMetadata = fread(file.path(paramDir, 'target_metadata.csv'))

########################################

dScreen = fread(file.path(dataDir, 'screen.csv.gz'))
setnames(dScreen, str_to_lower)
dScreen[, value_raw := str_to_lower(value_raw)]

dScreen = merge(dScreen, assayMetadata[, .(assay_id, assay_target, result_type)],
                by = 'assay_id')

dScreenQual = merge(dScreen[result_type == 'qual'], assayResultMetadata,
                    by = 'value_raw')
dScreenQual = unique(dScreenQual[, !'assay_id'])

########################################

dScreenDrugExp = fread(file.path(dataDir, 'screen_drug_exp.csv.gz'))
setnames(dScreenDrugExp, str_to_lower)

dDrugExpQual = merge(dScreenDrugExp, dScreenQual,
                     by = c('person_id', 'measurement_datetime'),
                     allow.cartesian = TRUE)

dSummaryQual = dDrugExpQual[, .(n_persons = uniqueN(person_id),
                                n_pos = sum(value_num == 1),
                                n_neg = sum(value_num == 0)),
                            by = .(assay_target, ingred_name)]

########################################

dCountsPersons = dScreenQual[, .(n_persons = uniqueN(person_id))]
fwrite(dCountsPersons, file.path(resultDir, 'counts_qual_persons.csv'))

dCountsMeas = dScreenQual[, .(n_meas = .N),
                          keyby = .(assay_target, value_num)]
dCountsMeas[, value_char := c('neg', 'pos')[value_num + 1L]]
dCountsMeas = dcast(dCountsMeas, assay_target ~ value_char, value.var = 'n_meas')
fwrite(dCountsMeas, file.path(resultDir, 'counts_qual_meas.csv'))

dCountsIngreds = merge(dDrugExpQual[, .(n_ingreds = uniqueN(ingred_name)),
                                    by = .(person_id, measurement_datetime)],
                       dScreenQual, by = c('person_id', 'measurement_datetime'), all.y = TRUE)
dCountsIngreds[is.na(n_ingreds), n_ingreds := 0]
fwrite(as.list(summary(dCountsIngreds$n_ingreds)),
       file.path(resultDir, 'counts_qual_ingreds.csv'))

########################################

dSummaryTargets = dSummaryQual[targetMetadata, on = c('assay_target', 'ingred_name')]

dStatsQualTargets = foreach(di = iter(dSummaryTargets, by = 'row'), .combine = rbind) %dopar% {
  dInput = getModelInput(dScreenQual, dDrugExpQual, di$assay_target, di$ingred_name)
  s = getLogisticStats(dInput, di$ingred_name, pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}

########################################

dSummaryKeep = dSummaryQual[n_persons >= params$min_persons][
  !targetMetadata, on = c('assay_target', 'ingred_name')]

timeStart = Sys.time()
dStatsQualNon = foreach(di = iter(dSummaryKeep, by = 'row'), .combine = rbind) %dopar% {
  ingredsNow = c(di$ingred_name, targetMetadata[assay_target == di$assay_target]$ingred_name)
  dInput = getModelInput(dScreenQual, dDrugExpQual, di$assay_target, ingredsNow)
  s = getLogisticStats(dInput, ingredsNow, pl = FALSE)
  s = cbind(di, dInput[, .(exposure_freq = sum(get(di$ingred_name)) / .N)], s)
  return(s)}
timeElapsedQual = Sys.time() - timeStart

dStatsQual = rbind(dStatsQualTargets, dStatsQualNon)
dStatsQual = cbind(dStatsQual, getAshStats(dStatsQual))
setorder(dStatsQual, assay_target, -PosteriorMean)

dStatsQual[, or_pm := exp(PosteriorMean)]
dStatsQual[, or_credint_lower := exp(credint_lower)]
dStatsQual[, or_credint_upper := exp(credint_upper)]

fwrite(dStatsQual, file.path(resultDir, 'stats_qual.csv'))

dStatsQualPos = dStatsQual[, .SD[1:params$n_top], by = assay_target]
fwrite(dStatsQualPos, file.path(resultDir, 'stats_qual_pos.csv'))

dStatsQualNeg = dStatsQual[, .SD[(.N - params$n_top + 1):.N][.N:1],
                           by = assay_target]
fwrite(dStatsQualNeg, file.path(resultDir, 'stats_qual_neg.csv'))
