scriptDir = 'scripts'
source(file.path(scriptDir, 'setup.R'))

params = fread(file.path(paramDir, 'analysis_params.csv'))
assayMetadata = fread(file.path(paramDir, 'assay_metadata.csv'))
assayResultMetadata = fread(file.path(paramDir, 'assay_result_metadata.csv'))
targetMetadata = fread(file.path(paramDir, 'target_metadata.csv'))

dStats = fread(file.path(resultDir, 'stats_qual.csv'))

########################################

dScreen = fread(file.path(dataDir, 'screen.csv.gz'))
setnames(dScreen, str_to_lower)
dScreen[, value_raw := str_to_lower(value_raw)]

dScreen = merge(dScreen, assayMetadata[, .(assay_id, assay_target, result_type)],
                by = 'assay_id')

dScreenQual = merge(dScreen[result_type == 'qual'], assayResultMetadata,
                    by = 'value_raw')
dScreenQual = unique(dScreenQual[, !'assay_id'])

dScreenDrugExp = fread(file.path(dataDir, 'screen_drug_exp.csv.gz'))
setnames(dScreenDrugExp, str_to_lower)

dDrugExpQual = merge(dScreenDrugExp, dScreenQual,
                     by = c('person_id', 'measurement_datetime'),
                     allow.cartesian = TRUE)

########################################

dStatsNow = dStats[, .SD[1:5], by = assay_target]
dStatsNow[, assay_target := paste(str_to_title(assay_target), 'assay')]

p = ggplot(dStatsNow) +
  facet_wrap(vars(assay_target), ncol = 2, scales = 'free') +
  geom_point(aes(y = reorder(ingred_name, or_pm), x = or_pm), size = 2,
             shape = 21) +
  geom_linerangeh(aes(y = reorder(ingred_name, or_pm),
                      xmin = or_credint_lower, xmax = or_credint_upper)) +
  labs(x = 'Odds ratio for positives', y = 'Medication') +
  scale_x_continuous(trans = 'log2', limits = c(0.9, 8.5))

ggsave(file.path(resultDir, 'stats_qual_pos.pdf'),
       plot = p, width = 5, height = 3.25)

########################################

assayTarget = 'acetaminophen'
dStatsNow = dStats[assay_target == assayTarget][1:5]

dWide = getModelInput(dScreenQual, dDrugExpQual, assayTarget, dStatsNow$ingred_name)
coexpMat = getCoexpFreq(dWide, dStatsNow$ingred_name, cluster = FALSE)

plotCoexpFreq(coexpMat, dStatsNow, NA, file.path(resultDir, 'coexp_acet_pos.pdf'),
              width = 3.5, height = 2.5)

########################################

ingreds = c('levodopa', 'entacapone',
            targetMetadata[assay_target == assayTarget]$ingred_name)
ingredIdxKeep = 1:length(ingreds)
dInput = getModelInput(dScreenQual, dDrugExpQual, assayTarget, ingreds)
s = getLogisticStats(dInput, ingreds, ingredIdxKeep = ingredIdxKeep)

s[, ingred_name := ingreds[ingredIdxKeep]]
s[, assay_target := assayTarget]
s[, or := exp(coef)]
setcolorder(s, c('assay_target', 'ingred_name'))
# not running ash because we only fit one model
fwrite(s, file.path(resultDir, 'stats_qual_dopa.csv'))

########################################

assayTarget = 'acetaminophen'
dStatsNow = dStats[assay_target == assayTarget, .SD[.N:(.N - params$n_top + 1)]]

dWide = getModelInput(dScreenQual, dDrugExpQual, assayTarget, dStatsNow$ingred_name)
coexpMat = getCoexpFreq(dWide, dStatsNow$ingred_name)

plotCoexpFreq(coexpMat, dStatsNow, NA, file.path(resultDir, 'coexp_acet_neg.pdf'),
              width = 4.3, height = 3.3)

########################################

assayTarget = 'ethanol'
dStatsNow = dStats[assay_target == assayTarget, .SD[.N:(.N - params$n_top + 1)]]

dWide = getModelInput(dScreenQual, dDrugExpQual, assayTarget, dStatsNow$ingred_name)
coexpMat = getCoexpFreq(dWide, dStatsNow$ingred_name)

plotCoexpFreq(coexpMat, dStatsNow, NA, file.path(resultDir, 'coexp_ethan_neg.pdf'),
              width = 4.3, height = 3.3)
