scriptDir = 'scripts'
source(file.path(scriptDir, 'setup.R'))

assayMetadata = fread(file.path(paramDir, 'assay_metadata.csv'))

dSpiking = fread(file.path(dataDir, 'spiking_experiments.csv'))
dSpiking = melt(dSpiking, id.vars = c('test_compound', 'test_conc'),
                variable.name = 'assay_id', value.name = 'target_conc',
                variable.factor = FALSE)

dSpiking[, test_compound_fac :=
           factor(test_compound, c('levodopa', 'carbidopa', 'entacapone',
                                   'methyldopa', 'alpha-methyldopamine',
                                   '3-o-methyldopa'))]

dSpikingAcet = dSpiking[assay_id == 'AcetSc']
cutoffAcet = assayMetadata[assay_id == 'AcetSc']$cutoff_ug_ml

########################################

dSpikingInterp = dSpikingAcet[, if (any(target_conc >= cutoffAcet))
  .SD[(which(target_conc >= cutoffAcet)[1] - 1):which(target_conc >= cutoffAcet)[1]],
  by = test_compound][
    , .(test_conc_cutoff = test_conc[1] + (cutoffAcet - target_conc[1]) *
          (test_conc[2] - test_conc[1]) / (target_conc[2] - target_conc[1])),
    by = test_compound]

dSpikingInterp = merge(dSpikingInterp, unique(dSpiking[, .(test_compound)]),
                       by = 'test_compound', all = TRUE)
setorderv(dSpikingInterp, 'test_conc_cutoff', na.last = TRUE)

fwrite(dSpikingInterp, file.path(resultDir, 'spiking_interp.csv'))

########################################

testCompounds1 = levels(dSpiking$test_compound_fac)[1:3]

p1 = plotSpiking(dSpikingAcet[test_compound %in% testCompounds1],
                 xBreaks = c(0, 5, 30, 100, 200, 400),
                 yBreaks = c(0, 1, 3, 5, 10, 15),
                 dInterp = dSpikingInterp, xText = 375, yText = 4.5)
p2 = plotSpiking(dSpikingAcet[!(test_compound %in% testCompounds1)],
                 xBreaks = c(0, 30, 150, 400, 800, 1600),
                 yBreaks = c(0, 3, 15, 50, 100, 200),
                 dInterp = dSpikingInterp, xText = 1500, yText = 10)

pData = plot_grid(p1, p2, align = 'hv', axis = 'tblr', ncol = 1)
pTitle = ggdraw() +
  draw_label('Registered acetaminophen conc. (\u03bcg/mL)',
             angle = 90, size = 12)

p = plot_grid(pTitle, pData, nrow = 1, rel_widths = c(0.05, 1))
ggsave(file.path(resultDir, 'spiking.pdf'), plot = p,
       width = 5, height = 4, device = cairo_pdf) # unicode requires cairo_pdf
